@@ -26,7 +26,7 @@ import socket
 
 
 # The current version of duplicity
-version = "0.7.02"
+version = "0.7.03"
 
 # Prefix for all files (appended before type-specific prefixes)
 file_prefix = ""
@@ -284,3 +284,6 @@ par2_options = ""
 
 # Whether to enable gio backend
 use_gio = False
+
+# If set, collect only the file status, not the whole root.
+file_changed = None
